[x] fetch orders and return data

[x] save to sqllite db

[x] progress bar

[x] cli configure

[x] cli fluff

[x] cleanup code with class instances, better variable names and comments

[x] add stats

[x] pass config flag

[x] retry mechanism for login

[x] handle exceptions in db

[x] graphs in term?

[x] sql as external file

[x] add readme

[x] add screenies, asciiterm

[ ] write blogpost

[x] publish on pypi

[x] test on ubuntu vagrant

### Next Version

[ ] email monthly reports
[ ] keep offset id in a text file, so that if there is a partial fetch, the complete fetch continues only from the fetch - \*Will do in next release
